# IRIS

IRIS is an intelligent runtime system for extremely heterogeneous architectures. IRIS discovers available functionality, manage multiple diverse programming
systems (e.g., OpenMP, CUDA, HIP, Level Zero, OpenCL, Hexagon) simultaneously in the same application, represents data dependencies, orchestrates data movement proactively, and allows configurable work schedulers for diverse heterogeneous devices.

IRIS is open source software. You may freely distribute it under the terms of the license agreement found in LICENSE.

### The IRIS source code will be available at this repository on September 2021.

[https://iris-programming.com](https://iris-programming.com)

